@@ -63,6 +63,8 @@ def create_prospect_report(data, quarter_name, output_path):
     workbook = writer.book
     target_list_sheet = writer.sheets["1_target_list"]
     full_details_sheet = writer.sheets["2_full_details"]
+
+    
     dollars_format = workbook.add_format({'num_format': '[$$-409]#,##0'})
     percent_format = workbook.add_format({'num_format': '0.0%'})
 
@@ -70,6 +72,7 @@ def create_prospect_report(data, quarter_name, output_path):
     full_details_sheet.set_column("E:E", None, dollars_format)
     full_details_sheet.set_column("J:J", None, dollars_format)
     full_details_sheet.set_column("F:F", None, percent_format)
+    
     autosize_columns(target_list_df, target_list_sheet)
     autosize_columns(full_details_df, full_details_sheet)
     target_list_sheet.autofilter("A1:C{end}".format(end=target_list_df.shape[0]))
@@ -78,6 +81,66 @@ def create_prospect_report(data, quarter_name, output_path):
     writer.save()
     writer.close()
 
+def create_prospect_report_v2(data, quarter_name, output_path):
+
+    data["current_percent_of_portfolio"] = data["current_percent_of_portfolio"] / 100
+    aum = get_aum(data)
+    target_list_df = pd.DataFrame(columns=["filer_name","AUM","Filtered Ticker Count", "Filtered Ticker List"])
+    target_list_df["filer_name"] = list(data["filer_name"].unique())
+    target_list_df["AUM"] = target_list_df["filer_name"].apply(lambda x: aum[x])
+    target_list_df = target_list_df[(target_list_df["AUM"] >= 500000000) & (target_list_df["AUM"] < 10000000000)]
+    target_list_df = target_list_df.sort_values("AUM", ascending=False)
+
+    full_details_df = data
+    full_details_df["AUM"] = full_details_df["filer_name"].apply(lambda x: aum[x])
+    full_details_df["NPD_Ticker"] = "NPD_Ticker"
+    full_details_df["stock_holding_morethan1pct"] = full_details_df["current_percent_of_portfolio"].apply(lambda x: "More than 1% of Portfolio" if x > 0.01 else "Other")
+    full_details_df = full_details_df[["filer_name","stock_name","stock_ticker","security_type","current_mv","current_percent_of_portfolio","source_date","sector","industry","AUM","NPD_Ticker","stock_holding_morethan1pct"]]
+    print(target_list_df)
+    writer = pd.ExcelWriter("{output_path}Prospect_Report_{quarter}.xlsx".format(output_path=output_path, quarter=quarter_name.replace("/","-")), engine="xlsxwriter")
+    target_list_df.to_excel(writer, index=False, sheet_name="1_target_list")
+    full_details_df.to_excel(writer, index=False, sheet_name="2_full_details")
+    workbook = writer.book
+    target_list_sheet = writer.sheets["1_target_list"]
+    full_details_sheet = writer.sheets["2_full_details"]
+
+    #add hidden rows
+    #full_details_sheet.write("O1", "=SUBTOTAL(109, N1)")
+    for i in range(len(full_details_df)):
+        m_cell = "M" + str(i+2)
+        n_cell = "N" + str(i+2)
+        full_details_sheet.write(m_cell, 1)
+        full_details_sheet.write_formula(n_cell, "=SUBTOTAL(109, {m_cell})".format(m_cell=m_cell))
+
+    #add dynamic ticker count
+    target_list_sheet.write("C1", "Filtered Ticker Count")
+    target_list_sheet.write("D1", "Filtered Tickers")
+    for i in range(len(target_list_df)):
+        a_cell = "A" + str(i+2)
+        c_cell = "C" + str(i+2)
+        d_cell = "D" + str(i+2)
+        target_list_sheet.write_formula(c_cell, '''=IF(LEN(TRIM({d_cell}))=0,0,(LEN(TRIM({d_cell}))-LEN(SUBSTITUTE({d_cell},", ","")))/2+1)'''.format(d_cell=d_cell))
+        target_list_sheet.write_formula(d_cell, '''=TEXTJOIN(", ", TRUE, UNIQUE(FILTER('2_full_details'!C:C, ('2_full_details'!A:A={a_cell})*('2_full_details'!N:N=1)*('2_full_details'!L:L="More than 1% of Portfolio"),"")))'''.format(a_cell=a_cell))
+    
+    dollars_format = workbook.add_format({'num_format': '[$$-409]#,##0'})
+    percent_format = workbook.add_format({'num_format': '0.0%'})
+
+    target_list_sheet.set_column("B:B", None, dollars_format)
+    full_details_sheet.set_column("E:E", None, dollars_format)
+    full_details_sheet.set_column("J:J", None, dollars_format)
+    full_details_sheet.set_column("F:F", None, percent_format)
+    full_details_sheet.set_column("M:M", None, None, {'hidden': True})
+    full_details_sheet.set_column("N:N", None, None, {'hidden': True})
+    
+    autosize_columns(target_list_df, target_list_sheet)
+    autosize_columns(full_details_df, full_details_sheet)
+
+    target_list_sheet.autofilter("B1:C{end}".format(end=target_list_df.shape[0]))
+    full_details_sheet.autofilter("A1:L{end}".format(end=full_details_df.shape[0]))
+    
+    writer.save()
+    writer.close()
+
 def create_client_report(data, npd_tickers, npd_clients, quarter_name, output_path, create_charts):
 
     #create summary holdings tab
@@ -163,7 +226,8 @@ def create_client_report(data, npd_tickers, npd_clients, quarter_name, output_pa
                     this_row = {0:0,1:0,2:1,3:1}[ind]
                     this_col = {0:0,1:1,2:0,3:1}[ind]
                     axis[this_row, this_col].barh(fund_data["stock_ticker"], fund_data["current_percent_of_portfolio"])
-                    axis[this_row, this_col].set_title(fund, fontsize=9)
+                    fund_name = "Enterprise" if fund == "NA" else fund
+                    axis[this_row, this_col].set_title(fund_name, fontsize=9)
                 plt.figtext(0.5, 0.01, "Source: WhaleWisdom.com", ha="center", fontsize=8)
                 if len(quad) < 4:
                     axis.flat[-1].set_visible(False)
