@@ -1,11 +1,11 @@
-from WhaleWisdom.FundHoldings.report_builder import create_client_report, create_prospect_report
+from WhaleWisdom.FundHoldings.report_builder import create_client_report, create_prospect_report, create_prospect_report_v2
 import pandas as pd
 from WhaleWisdom.Common.npd_data import *
 from WhaleWisdom.FundHoldings.report_data import *
 import datetime
 import os
 
-def main(report_type, quarter, npd_tickers, npd_clients, manual, output_path, create_charts):
+def main(report_type, quarter, npd_tickers, npd_clients, manual, output_path, create_charts, prospect_v2=True):
 
     if manual:
         print("Cross referencing ticker data...")
@@ -20,7 +20,10 @@ def main(report_type, quarter, npd_tickers, npd_clients, manual, output_path, cr
         if manual:
             print("Prospect report data retrieved...")
             print("Building Prospect Report...")
-        create_prospect_report(data, quarter, output_path)
+        if prospect_v2:
+            create_prospect_report_v2(data, quarter, output_path)
+        else:
+            create_prospect_report(data, quarter, output_path)
         if manual:
             print("Prospect report finished...")
     elif report_type == "Client":
